@@ -1,5 +1,7 @@
+####################################################
 #### Dialogs boxes for RcmdrPlugin.EcoVirtual package
 ### Alexandre Adalardo de Oliveira 17 fevereiro 2010
+### version: JAN 2016
 ####################################################
 ## por padrao .First.lib nao existe mais
 # .First.lib <- function(libname, pkgname){
@@ -15,8 +17,7 @@
 #     }
 ####################################################
 ## usando a funcao do RcmdrPlugin.TeachingDemo (Jonh Fox)
-# Note: the following function (with contributions from Richard Heiberger and Milan Bouchet-Valat) 
-# can be included in any Rcmdr plug-in package to cause the package to load
+# Note: the following function (with contributions from Richard Heiberger and Milan Bouchet-Valat)# can be included in any Rcmdr plug-in package to cause the package to load
 # the Rcmdr if it is not already loaded
 .onAttach <- function(libname, pkgname){
     if (!interactive()) return()
@@ -37,29 +38,34 @@
         }
     }
 }
-
-
 ########################################################
 estDemDb <-function () 
 {
+dialogName<-"estDemDb" ### 
+def <- list(dsname="Do_Not_Save", no=10, b= 0.2,d=0.2, tmax=10, npop=20, nmax=10000, barpr= 0) # lista de argumentos padrao
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Demographic Stochasticity"))
 #### Salva dados
-dsname <- tclVar("Do_Not_Save")
+dsname <- tclVar(initial$dsname)
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-noVar <- tclVar("100")
+noVar <- tclVar(initial$no)
 noEntry <- tkentry(top, width = "4", textvariable = noVar)
-bVar <- tclVar(0.2)
+bVar <- tclVar(initial$b)
 bEntry <- tkentry(top, width = "6", textvariable = bVar)
-dVar <- tclVar(0.2)
+dVar <- tclVar(initial$d)
 dEntry <- tkentry(top, width = "6", textvariable = dVar)
-tmaxVar <- tclVar(50)
+tmaxVar <- tclVar(initial$tmax)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
-npopVar <-tclVar("20")
+npopVar <-tclVar(initial$npop)
 npopEntry <- tkentry(top, width = "3", textvariable = npopVar)
+nmaxVar <-tclVar(initial$nmax)
+nmaxEntry <- tkentry(top, width = "5", textvariable = nmaxVar)
+barprVar <- tclVar(initial$barpr)
+barprEntry <- tkcheckbutton(top, variable = barprVar)
 	onOK <- function() 
 	{
-        #closeDialog()
+        closeDialog()
         N0 <- round(as.numeric(tclvalue(noVar)))
         if (is.na(N0) || N0 <= 0) 
         {
@@ -75,21 +81,24 @@ npopEntry <- tkentry(top, width = "3", textvariable = npopVar)
         b=as.numeric(tclvalue(bVar))
         d=as.numeric(tclvalue(dVar))
         npop=as.numeric(tclvalue(npopVar))
+        nmax=as.numeric(tclvalue(nmaxVar))
+        barpr <- as.logical(as.numeric(tclvalue(barprVar)))
 ############ Data name
 ##estDem(tmax=10, n=0.2, m=0.2, N0=10, nsim=20, ciclo=5000)
    dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
         {
-        	command <- paste("estDem(tmax= ",tmax, ", b = ", b,", d = ", d,", N0 =", N0, ", nsim = ", npop, ")", sep = "")
+        	command <- paste("estDem(tmax= ",tmax, ", b = ", b,", d = ", d,", N0 =", N0, ", nsim = ", npop,", nmax =", nmax,", barpr =", barpr, ")", sep = "")
         }
         else  
 		  {
-		  command <- paste(dsnameValue, " <- estDem(tmax= ",tmax, ", b = ", b,", d = ", d,", N0 =", N0, ", nsim = ", npop, ")", sep = "")
+		  command <- paste(dsnameValue, " <- estDem(tmax= ",tmax, ", b = ", b,", d = ", d,", N0 =", N0, ", nsim = ", npop,", nmax =", nmax, ", barpr =", barpr, ")", sep = "")
 		  }
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
+        putDialog(dialogName, values = list(dsname=dsnameValue, no=as.numeric(tclvalue(noVar)), b=as.numeric(tclvalue(bVar)), d=as.numeric(tclvalue(dVar)), tmax=as.numeric(tclvalue(tmaxVar)), npop=as.numeric(tclvalue(npopVar)), nmax=as.numeric(tclvalue(nmaxVar)), barpr=  as.logical(as.numeric(tclvalue(barprVar))) ), resettable = FALSE)
 	}
-OKCancelHelp(helpSubject = "dynPop")
+OKCancelHelp(helpSubject = "dynPop", reset=dialogName, apply=dialogName)
 tkgrid(tklabel(top, text="Enter name for data set: "), entryDsname, sticky="e")
 #tkgrid(tklabel(top, text="Simulation Conditions :  ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Maximum time "), tmaxEntry, sticky = "e")
@@ -98,6 +107,10 @@ tkgrid(tklabel(top, text="Population parameters :", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Initial size  "), noEntry, sticky = "e")
 tkgrid(tklabel(top, text = "Birth rate  "), bEntry, sticky = "se")
 tkgrid(tklabel(top, text = "Death rate  "), dEntry, sticky = "e")
+
+tkgrid(tklabel(top, text="Restrictions for long simulations:", fg="blue"), sticky="w")
+tkgrid(tklabel(top, text = "Maximum population size  "), nmaxEntry, sticky = "e")
+tkgrid(tklabel(top, text = "Show progress bar for each simulation"), barprEntry, sticky = "e")
 tkgrid(buttonsFrame, sticky = "w", columnspan = 2)
 #tkgrid(tklabel(top, text="Enter name for data set:"), entryDsname, sticky="e")
 tkgrid.configure(entryDsname, sticky = "w")
@@ -106,38 +119,44 @@ tkgrid.configure(npopEntry, sticky = "w")
 tkgrid.configure(noEntry, sticky = "w")
 tkgrid.configure(bEntry, sticky = "w")
 tkgrid.configure(dEntry, sticky = "w")
-dialogSuffix(rows = 6, columns = 2, focus = tmaxEntry)
+###
+tkgrid.configure(nmaxEntry, sticky = "w")
+tkgrid.configure(barprEntry, sticky = "w")
+dialogSuffix(rows = 9, columns = 2, focus = tmaxEntry)
 }
 #########################################################
 #########################################################
 popExpDb<-function()
 {
+dialogName<-"popExpDb" ### inserido
+def <- list(dsname="Do_Not_Save", noVar=10, lambVar= 1.05,tmaxVar=10,inttVar=1) # inserido
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Exponential Growth"))
 #### Salva dados
-dsname <- tclVar("Do_Not_Save")
+dsname <- tclVar(initial$dsname)
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-noVar <- tclVar("10")
+noVar <- tclVar(initial$noVar)
 noEntry <- tkentry(top, width = "4", textvariable = noVar)
-lambVar <- tclVar(1.05)
-tmaxVar <- tclVar(10)
+lambVar <- tclVar(initial$lambVar)
+tmaxVar <- tclVar(initial$tmaxVar)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
-inttVar<-tclVar(1.00)
+inttVar<-tclVar(initial$inttVar)
 #########################
-	set.gr=function(...)
-	{
-#extVF <- as.logical(as.numeric(tclvalue(extVar)))
-	command=paste("popExp(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", tmax = ", as.numeric(tclvalue(tmaxVar)),", intt = ", as.numeric(tclvalue(inttVar)),")", sep="")
-	doItAndPrint(command)
-#	tkfocus(CommanderWindow())
-	}
+## 	set.gr=function(...)
+## 	{
+## #extVF <- as.logical(as.numeric(tclvalue(extVar)))
+## 	command=paste("popExp(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", tmax = ", as.numeric(tclvalue(tmaxVar)),", intt = ", as.numeric(tclvalue(inttVar)),")", sep="")
+## 	doItAndPrint(command)
+## #	tkfocus(CommanderWindow())
+## 	}
 ##########################
-lambEntry<-tkscale(top, from=0, to=5, showvalue=TRUE, variable=lambVar, resolution=0.01, orient="horizontal", 
-command=set.gr)
-inttEntry <- tkscale(top, from=0.01, to=1, showvalue=TRUE, variable=inttVar, resolution=0.01, orient="horizontal",command=set.gr)
+lambEntry<-tkscale(top, from=0, to=5, showvalue=TRUE, variable=lambVar, resolution=0.01, orient="horizontal") #, command=set.gr)
+inttEntry <- tkscale(top, from=0.01, to=1, showvalue=TRUE, variable=inttVar, resolution=0.01, orient="horizontal")#,command=set.gr)
 ################################################
 	onOK <- function() 
-	{	
+            {
+             closeDialog()
 ############ Data name
    dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
@@ -147,12 +166,13 @@ inttEntry <- tkscale(top, from=0.01, to=1, showvalue=TRUE, variable=inttVar, res
         else  
 		  {
 		  command <- paste(dsnameValue, " <- popExp(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", tmax = ", as.numeric(tclvalue(tmaxVar)),", intt = ", as.numeric(tclvalue(inttVar)),")", sep="")
-		  }
-	doItAndPrint(command)
-	tkfocus(CommanderWindow())
+              }
+   doItAndPrint(command)
+   tkfocus(CommanderWindow())
+   putDialog(dialogName, values = list(dsname=dsnameValue, noVar=as.numeric(tclvalue(noVar)), lambVar=as.numeric(tclvalue(lambVar)), tmaxVar=as.numeric(tclvalue(tmaxVar)), inttVar=as.numeric(tclvalue(inttVar))), resettable = FALSE) ## inserido
 	}
 #popExp(N0,lamb,tmax, intt= 1) 
-OKCancelHelp(helpSubject = "dynPop")
+OKCancelHelp(helpSubject = "dynPop", reset=dialogName, apply=dialogName) # modificado
 tkgrid(tklabel(top, text="Enter name for last simulation data set: "), entryDsname, sticky="e")
 #tkgrid(tklabel(top, text="Simulation Arena Conditions :  ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Maximum time"), tmaxEntry, sticky = "e")
@@ -160,7 +180,6 @@ tkgrid(tklabel(top, text = "Interval time size "), inttEntry, sticky = "e")
 tkgrid(tklabel(top, text="Species parameters :", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Initial population size  "), noEntry, sticky = "e")
 tkgrid(tklabel(top, text = "Population growth rate (lambda)  "), lambEntry, sticky = "e")
-
 tkgrid(buttonsFrame, sticky = "w", columnspan = 2)
 #tkgrid(tklabel(top, text="Enter name for data set:"), entryDsname, sticky="e")
 tkgrid.configure(entryDsname, sticky = "w")
@@ -173,51 +192,57 @@ dialogSuffix(rows = 6, columns = 2, focus = tmaxEntry)
 ############################################################
 estEnvDb <-function () 
 {
+dialogName<-"estEnvDb" ### 
+def <- list(dsname="Do_Not_Save", noVar=10, lambVar= 1.05, varrVar= .05,tmaxVar=10, npopVar=20, extVar=0) # lista de argumentos padrao
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Environmental Sthocasticity"))
 #### Salva dados
 dsname <- tclVar("Do_Not_Save")
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-noVar <- tclVar("10")
+noVar <- tclVar(initial$noVar)
 noEntry <- tkentry(top, width = "4", textvariable = noVar)
-lambVar <- tclVar(1.05)
-varrVar <- tclVar(0.02)
-tmaxVar <- tclVar(100)
+lambVar <- tclVar(initial$lambVar)
+varrVar <- tclVar(initial$varrVar)
+tmaxVar <- tclVar(initial$tmaxVar)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
-npopVar<-tclVar("20")
+npopVar<-tclVar(initial$npopVar)
 npopEntry <- tkentry(top, width = "4", textvariable = npopVar)
-extVar <- tclVar("0")
+extVar <- tclVar(initial$extVar)
 extBox <- tkcheckbutton(top, variable = extVar)
 #################################################################
-	set.gr=function(...)
-	{
-#extVF <- as.logical(as.numeric(tclvalue(extVar)))
-	command=paste("estEnv(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", varr = ", as.numeric(tclvalue(varrVar)),", tmax = ", as.numeric(tclvalue(tmaxVar)),", npop = ", as.numeric(tclvalue(npopVar)), ", ext =", as.logical(as.numeric(tclvalue(extVar))), ")", sep="")
-	doItAndPrint(command)
-#	tkfocus(CommanderWindow())
-	}
+## function to reset simulation when change tkscale
+## 	set.gr=function(...)
+## 	{
+## #extVF <- as.logical(as.numeric(tclvalue(extVar)))
+## 	command=paste("estEnv(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", varr = ", as.numeric(tclvalue(varrVar)),", tmax = ", as.numeric(tclvalue(tmaxVar)),", npop = ", as.numeric(tclvalue(npopVar)), ", ext =", as.logical(as.numeric(tclvalue(extVar))), ")", sep="")
+## 	doItAndPrint(command)
+## #	tkfocus(CommanderWindow())
+## 	}
 ##############################################################
-lambEntry<-tkscale(top, from=0, to=5, showvalue=TRUE, variable=lambVar, resolution=0.01, orient="horizontal", 
-command=set.gr)
-varrEntry <- tkscale(top, from=0, to=15, showvalue=TRUE, variable=varrVar, resolution=0.01, orient="horizontal", 
-command=set.gr)
+lambEntry<-tkscale(top, from=0, to=5, showvalue=TRUE, variable=lambVar, resolution=0.01, orient="horizontal")# 
+#,command=set.gr)
+varrEntry <- tkscale(top, from=0, to=15, showvalue=TRUE, variable=varrVar, resolution=0.01, orient="horizontal") 
+#,command=set.gr)
 ################################################
-	onOK <- function() 
-	{	
+onOK <- function() 
+    {
+        closeDialog()
 ############ Data name
-   dsnameValue <- trim.blanks(tclvalue(dsname))
+        dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
-        {
+            {
         	command <- paste("estEnv(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", varr = ", as.numeric(tclvalue(varrVar)),", tmax = ", as.numeric(tclvalue(tmaxVar)),", npop = ", as.numeric(tclvalue(npopVar)), ", ext =", as.logical(as.numeric(tclvalue(extVar))), ")", sep = "")
-        }
+            }
         else  
-		  {
-		  command <- paste(dsnameValue, " <- estEnv(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", varr = ", as.numeric(tclvalue(varrVar)),", tmax = ", as.numeric(tclvalue(tmaxVar)),", npop = ", as.numeric(tclvalue(npopVar)), ", ext =", as.logical(as.numeric(tclvalue(extVar))), ")", sep = "")
-		  }
+            {
+                command <- paste(dsnameValue, " <- estEnv(N0 = ", as.numeric(tclvalue(noVar)), ", lamb = ", as.numeric(tclvalue(lambVar)), ", varr = ", as.numeric(tclvalue(varrVar)),", tmax = ", as.numeric(tclvalue(tmaxVar)),", npop = ", as.numeric(tclvalue(npopVar)), ", ext =", as.logical(as.numeric(tclvalue(extVar))), ")", sep = "")
+            }
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
-	}
-OKCancelHelp(helpSubject = "dynPop")
+        putDialog(dialogName, values = list(dsname=dsnameValue, noVar=as.numeric(tclvalue(noVar)), lambVar=as.numeric(tclvalue(lambVar)), varrVar=as.numeric(tclvalue(varrVar)), tmaxVar=as.numeric(tclvalue(tmaxVar)), npopVar=as.numeric(tclvalue(npopVar)), extVar=as.numeric(tclvalue(extVar))), resettable = FALSE)
+    }
+OKCancelHelp(helpSubject = "dynPop", reset=dialogName, apply=dialogName)
 tkgrid(tklabel(top, text="Enter name for last simulation data set: "), entryDsname, sticky="e")
 #tkgrid(tklabel(top, text="Simulation Arena Conditions :  ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Maximum time"), tmaxEntry, sticky = "e")
@@ -228,7 +253,6 @@ tkgrid(tklabel(top, text = "Population growth rate (lambda) "), lambEntry, stick
 tkgrid(tklabel(top, text="Environment stochasticity: ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "lambda variance "), varrEntry, sticky = "e")
 tkgrid(tklabel(top, text = "Population Extinction"), extBox, sticky = "e")
-
 tkgrid(buttonsFrame, sticky = "w", columnspan = 2)
 #tkgrid(tklabel(top, text="Enter name for data set:"), entryDsname, sticky="e")
 tkgrid.configure(entryDsname, sticky = "w")
@@ -241,58 +265,64 @@ tkgrid.configure(extBox, sticky = "w")
 dialogSuffix(rows = 6, columns = 2, focus = tmaxEntry)
 }
 #########################################################
-##########################################################
+#########################################################
 #crescLog(N0=10, r=0.05, K=80, tmax=100)
 popLogDb<-function () 
 {
+dialogName<-"popLogDb" 
+def <- list(dsname="Do_Not_Save", noVar=10, rVar= 0.05, kVar=100, tmaxVar=100, extVar=0)
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Logistic Growth"))
 #### Salva dados
-dsname <- tclVar("Do_Not_Save")
+dsname <- tclVar(initial$dsname)
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-noVar <- tclVar("10")
-rVar <- tclVar(0.05)
-kVar <- tclVar("20")
-tmaxVar <- tclVar(100)
+noVar <- tclVar(initial$noVar)
+rVar <- tclVar(initial$rVar)
+kVar <- tclVar(initial$kVar)
+tmaxVar <- tclVar(initial$tmaxVar)
 noEntry <- tkentry(top, width = "4", textvariable = noVar)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
 kEntry<-tkentry(top, width = "4", textvariable = kVar)
-extVar <- tclVar("0")
+extVar <- tclVar(initial$extVar)
 extBox <- tkcheckbutton(top, variable = extVar)
 #################################################################
-	set.gr=function(...)
-	{
-	command <- paste("popLog(N0= ", as.numeric(tclvalue(noVar)), ", r = ", as.numeric(tclvalue(rVar)),", K = ", as.numeric(tclvalue(kVar)),", tmax =", round(as.numeric(tclvalue(tmaxVar))), ", ext =", as.logical(as.numeric(tclvalue(extVar))),")", sep = "")
-	doItAndPrint(command)
-#	tkfocus(CommanderWindow())
-	}
+# funcao da atualizacao pelo barra de rolagem
+## set.gr=function(...)
+## 	{
+## 	command <- paste("popLog(N0= ", as.numeric(tclvalue(noVar)), ", r = ", as.numeric(tclvalue(rVar)),", K = ", as.numeric(tclvalue(kVar)),", tmax =", round(as.numeric(tclvalue(tmaxVar))), ", ext =", as.logical(as.numeric(tclvalue(extVar))),")", sep = "")
+## 	doItAndPrint(command)
+## #	tkfocus(CommanderWindow())
+## 	}
 ##############################################################
-rEntry <-tkscale(top, from=-5, to=5, showvalue=TRUE, variable=rVar, resolution=0.01, orient="horizontal", command=set.gr)
+rEntry <-tkscale(top, from=-5, to=5, showvalue=TRUE, variable=rVar, resolution=0.01, orient="horizontal")
+                                       #, command=set.gr)
 #kEntry <- tkscale(top, from=0, to= 10*as.numeric(tclvalue(noVar)), showvalue=TRUE, variable=kVar, resolution=round(0.1*as.numeric(tclvalue(noVar))), orient="horizontal", command=set.gr)
 ##############################################################
-	onOK <- function() 
-	{
-N0 <- round(as.numeric(tclvalue(noVar)))
+onOK <- function() 
+    {
+        closeDialog()            
+        N0 <- round(as.numeric(tclvalue(noVar)))
 #kEntry <- tkscale(top, from=0, to= 10*N0, showvalue=TRUE, variable=kVar, resolution=round(0.1*N0), orient="horizontal")
-tmax <- round(as.numeric(tclvalue(tmaxVar)))
-K <- as.numeric(tclvalue(kVar))
-r=as.numeric(tclvalue(rVar))
-#closeDialog()
+        tmax <- round(as.numeric(tclvalue(tmaxVar)))
+        K <- as.numeric(tclvalue(kVar))
+        r=as.numeric(tclvalue(rVar))
 ############ Data name
-   dsnameValue <- trim.blanks(tclvalue(dsname))
+        dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
-        {
+            {
         	command <- paste("popLog(N0= ",N0, ", r = ", r,", K = ", K,", tmax =", tmax, ", ext =", as.logical(as.numeric(tclvalue(extVar))),")", sep = "")
-        }
+            }
         else  
-		  {
-		  command <- paste(dsnameValue,"<-popLog(N0= ",N0, ", r = ", r,", K = ", K,", tmax =", tmax, ", ext =", as.logical(as.numeric(tclvalue(extVar))),")", sep = "")
-		  }
+            {
+                command <- paste(dsnameValue,"<-popLog(N0= ",N0, ", r = ", r,", K = ", K,", tmax =", tmax, ", ext =", as.logical(as.numeric(tclvalue(extVar))),")", sep = "")
+            }
 ########
+        putDialog(dialogName, values = list(dsname= dsnameValue, noVar=as.numeric(tclvalue(noVar)), rVar= as.numeric(tclvalue(rVar)), kVar= as.numeric(tclvalue(kVar)) , tmaxVar=as.numeric(tclvalue(tmaxVar)), extVar=as.logical(as.numeric(tclvalue(extVar)))), resettable = FALSE)
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
 	}
-OKCancelHelp(helpSubject = "dynPop")
+OKCancelHelp(helpSubject = "dynPop", reset=dialogName, apply=dialogName)
 tkgrid(tklabel(top, text="Enter name for data set: "), entryDsname, sticky="e")
 #tkgrid(tklabel(top, text="Simulation Arena Conditions : ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Maximum time "), tmaxEntry, sticky = "e")
@@ -309,23 +339,25 @@ tkgrid.configure(kEntry, sticky = "w")
 tkgrid.configure(rEntry, sticky = "w")
 tkgrid.configure(extBox, sticky = "w")
 dialogSuffix(rows = 6, columns = 2, focus = tmaxEntry)
-}
+} 
 ##########################################
-#compLV(n01=10, n02=10,r1=0.05, r2=0.03, k1=80, k2=50, alfa=1.2, beta=0.5, tmax=200)
 ##########################################
 logBifDb<-function () 
 {
+dialogName<-"logBifDb" 
+def <- list(dsname="Do_Not_Save", noVar=10, rdminVar= 1, rdmaxVar=3, nrdVar=500, kVar=20, tmaxVar=200)
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Logistic Bifurcation"))
 #### Salva dados
-dsname <- tclVar("Do_Not_Save")
+dsname <- tclVar(initial$dsname)
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-noVar <- tclVar("10")
-rdminVar <- tclVar(1)
-rdmaxVar <- tclVar(3)
-kVar <- tclVar("20")
-nrdVar <- tclVar("500")
-tmaxVar <- tclVar(200)
+noVar <- tclVar(initial$noVar)
+rdminVar <- tclVar(initial$rdminVar)
+rdmaxVar <- tclVar(initial$rdmaxVar)
+kVar <- tclVar(initial$kVar)
+nrdVar <- tclVar(initial$nrdVar)
+tmaxVar <- tclVar(initial$tmax)
 noEntry <- tkentry(top, width = "4", textvariable = noVar)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
 kEntry<-tkentry(top, width = "4", textvariable = kVar)
@@ -343,38 +375,36 @@ nrdEntry<-tkentry(top, width = "4", textvariable = nrdVar)
 rdminEntry <-tkscale(top, from= 1, to=2.999, showvalue=TRUE, variable=rdminVar, resolution=0.001, orient="horizontal")#, command=set.gr
 rdmaxEntry <-tkscale(top, from= 2, to=3, showvalue=TRUE, variable=rdmaxVar, resolution=0.001, orient="horizontal")
 nrdEntry<-tkscale(top, from= 100, to=1000, showvalue=TRUE, variable=nrdVar, resolution=100, orient="horizontal")
-#kEntry <- tkscale(top, from=0, to= 10*as.numeric(tclvalue(noVar)), showvalue=TRUE, variable=kVar, resolution=round(0.1*as.numeric(tclvalue(noVar))), orient="horizontal", command=set.gr)
 ##############################################################
-	onOK <- function() 
-	{
-N0 <- round(as.numeric(tclvalue(noVar)))
-#kEntry <- tkscale(top, from=0, to= 10*N0, showvalue=TRUE, variable=kVar, resolution=round(0.1*N0), orient="horizontal")
-tmax <- round(as.numeric(tclvalue(tmaxVar)))
-K <- as.numeric(tclvalue(kVar))
-   if (K <= N0) 
-     {
-     errorCondition("K should be larger than N0")
-     return()
-     }
-nrd <- as.numeric(tclvalue(nrdVar))
-rdmin=as.numeric(tclvalue(rdminVar))
-rdmax=as.numeric(tclvalue(rdmaxVar))
-#bifAttr(N0, K, tmax, nrd,maxrd=3, minrd=1)
-############ Data name
-   dsnameValue <- trim.blanks(tclvalue(dsname))
+onOK <- function() 
+    {
+        closeDialog()
+        N0 <- round(as.numeric(tclvalue(noVar)))
+        tmax <- round(as.numeric(tclvalue(tmaxVar)))
+        K <- as.numeric(tclvalue(kVar))
+        if (K <= N0) 
+            {
+                errorCondition("K should be larger than N0")
+                return()
+            }
+        nrd <- as.numeric(tclvalue(nrdVar))
+        rdmin=as.numeric(tclvalue(rdminVar))
+        rdmax=as.numeric(tclvalue(rdmaxVar))
+        dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
-        {
+            {
         	command <- paste("bifAttr(N0= ",N0, ", K = ", K, ", tmax =", tmax, ", nrd = ", nrd, ", minrd = ", rdmin,", maxrd = ", rdmax,")", sep = "")
-        }
+            }
         else  
-		  {
-		  command <- paste(dsnameValue,"<-bifAttr(N0= ",N0, ", K = ", K, ", tmax =", tmax, ", nrd = ", nrd, ", minrd = ", rdmin,", maxrd = ", rdmax,")", sep = "")
-		  }
+            {
+                command <- paste(dsnameValue,"<-bifAttr(N0= ",N0, ", K = ", K, ", tmax =", tmax, ", nrd = ", nrd, ", minrd = ", rdmin,", maxrd = ", rdmax,")", sep = "")
+            }
 ########
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
+        putDialog(dialogName, values = list(dsname=dsnameValue, noVar=as.numeric(tclvalue(noVar)), kVar=as.numeric(tclvalue(kVar)), tmaxVar=as.numeric(tclvalue(tmaxVar)), rdminVar=as.numeric(tclvalue(rdminVar)), rdmaxVar=as.numeric(tclvalue(rdmaxVar)), nrdVar=as.numeric(tclvalue(nrdVar))), resettable = FALSE)
 	}
-OKCancelHelp(helpSubject = "dynPop")
+OKCancelHelp(helpSubject = "dynPop", reset=dialogName, apply=dialogName)
 tkgrid(tklabel(top, text="Enter name for data set:  "), entryDsname, sticky="e")
 #tkgrid(tklabel(top, text="Simulation Arena Conditions : ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Time to convergence  "), tmaxEntry, sticky = "e")
@@ -400,31 +430,34 @@ dialogSuffix(rows = 7, columns = 2, focus = tmaxEntry)
 ##########################################
 compDb<-function () 
 {
+dialogName<-"compDb" ### 
+def <- list(dsname="Do_Not_Save", n01Var=10, n02Var=10, r1Var= 0.05, r2Var= 0.05, k1Var= 100, k2Var= 100, alfaVar= 1.2, betaVar= 0.5, tmaxVar=100) # lista de argumentos padrao
+initial <- getDialog(dialogName, defaults= def)
 initializeDialog(title = gettextRcmdr("Competition LV Model"))
 #### Salva dados
-dsname <- tclVar("Do_Not_Save")
+dsname <- tclVar(initial$dsname)
 entryDsname <- tkentry(top, width="20", textvariable=dsname)
 ####
-n01Var <- tclVar("10")
+n01Var <- tclVar(initial$n01Var)
 n01Entry <- tkentry(top, width = "4", textvariable = n01Var)
-n02Var <- tclVar("10")
+n02Var <- tclVar(initial$n02Var)
 n02Entry <- tkentry(top, width = "4", textvariable = n02Var)
-r1Var <- tclVar(0.05)
+r1Var <- tclVar(initial$r1Var)
 r1Entry=tkscale(top, from=-5, to=5, showvalue=TRUE, variable=r1Var, resolution=0.01, orient="horizontal")
-r2Var <- tclVar(0.05)
+r2Var <- tclVar(initial$r2Var)
 r2Entry=tkscale(top, from=-5, to=5, showvalue=TRUE, variable=r2Var, resolution=0.01, orient="horizontal")
-k1Var <- tclVar("20")
+k1Var <- tclVar(initial$k1Var)
 k1Entry <- tkentry(top, width = "4", textvariable = k1Var)
-k2Var <- tclVar("20")
+k2Var <- tclVar(initial$k2Var)
 k2Entry <- tkentry(top, width = "4", textvariable = k2Var)
-alfaVar <- tclVar("1.2")
+alfaVar <- tclVar(initial$alfa)
 alfaEntry <- tkentry(top, width = "6", textvariable = alfaVar)
-betaVar <- tclVar("0.5")
+betaVar <- tclVar(initial$beta)
 betaEntry <- tkentry(top, width = "6", textvariable = betaVar)
-tmaxVar <- tclVar(100)
+tmaxVar <- tclVar(initial$tmaxVar)
 tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
-	onOK <- function() 
-	{
+onOK <- function() 
+    {
         closeDialog()
         n01 <- round(as.numeric(tclvalue(n01Var)))
         if (is.na(n01) || n01 <= 0) 
@@ -461,23 +494,23 @@ tmaxEntry <- tkentry(top, width = "4", textvariable = tmaxVar)
         alfa=as.numeric(tclvalue(alfaVar))
         beta=as.numeric(tclvalue(betaVar))
 ############ Data name
-   dsnameValue <- trim.blanks(tclvalue(dsname))
+        dsnameValue <- trim.blanks(tclvalue(dsname))
         if (dsnameValue == "Do_Not_Save" | dsnameValue=="") 
-        {
+            {
         	command <- paste("compLV(n01= ",n01, ",n02= ",n02, ", r1 = ", r1,", r2 = ", r2,", k1 = ", k1,", k2 = ", k2,", alfa = ", alfa,", beta = ", beta,", tmax =", tmax,")", sep = "")
         }
         else  
-		  {
-		  command <- paste("compLV(n01= ",n01, "n02= ",n02, ", r1 = ", r1,", r2 = ", r2,", k1 = ", k1,", k2 = ", k2,", alfa = ", alfa,", beta = ", beta,", tmax =", tmax,")", sep = "")
+            {
+                command <- paste(dsnameValue, " <- compLV(n01= ",n01, ", n02= ",n02, ", r1 = ", r1,", r2 = ", r2,", k1 = ", k1,", k2 = ", k2,", alfa = ", alfa,", beta = ", beta,", tmax =", tmax,")", sep = "")
 		  }
-#compLV(n01=10, n02=10,r1=0.05, r2=0.03, k1=80, k2=50, alfa=1.2, beta=0.5, tmax=200)
 ########
 	doItAndPrint(command)
 	tkfocus(CommanderWindow())
+        putDialog(dialogName, values = list(dsname="Do_Not_Save", n01Var=round(as.numeric(tclvalue(n01Var))), n02Var=round(as.numeric(tclvalue(n02Var))), r1Var= as.numeric(tclvalue(r1Var)), r2Var= as.numeric(tclvalue(r2Var)), k1Var= as.numeric(tclvalue(k1Var)), k2Var= as.numeric(tclvalue(k2Var)), alfaVar= as.numeric(tclvalue(alfaVar)), betaVar= as.numeric(tclvalue(betaVar)), tmaxVar=as.numeric(tclvalue(tmaxVar))), resettable = FALSE)
 	}
-OKCancelHelp(helpSubject = "compLV")
+OKCancelHelp(helpSubject = "compLV", reset=dialogName, apply=dialogName)
 tkgrid(tklabel(top, text="Enter name for data set:"), entryDsname, sticky="e")
-tkgrid(tklabel(top, text = "Number of simulations  "), tmaxEntry, sticky = "e")
+tkgrid(tklabel(top, text = "Maximum time   "), tmaxEntry, sticky = "e")
 tkgrid(tklabel(top, text="Best competitor species parameters : ", fg="blue"), sticky="w")
 tkgrid(tklabel(top, text = "Initial population  "), n01Entry, sticky = "e")
 tkgrid(tklabel(top, text = "Carrying capacity (K)  "), k1Entry, sticky = "e")
@@ -631,5 +664,4 @@ tkgrid.configure(njEntry, sticky = "w")
 tkgrid.configure(naEntry, sticky = "w")
 dialogSuffix(rows = 14, columns = 2, focus = tmaxEntry)
 }
-############################################################
-
+########################END####################################
